****************************
Acknowledgements and funding
****************************

BCF thanks PA Gowaty (PAG), SP Hubbell (SPH), and M Reasel for their support and comments on this manuscript.  [TCG thanks here...]

Startup funds from the University of California to PAG and SPH; a Smithsonian Scholarly Studies Grant to SPH; `NSF grant #0948585 to SPH <http://www.nsf.gov/awardsearch/showAward.do?AwardNumber=0948585>`_; an `Amazon Web Services Education grant <http://aws.amazon.com/education/>`_ to TCG, BCF, and NG Crawford; [TCG support here...] provided financial support for this work.